@@ -7,7 +7,7 @@ use atelier_test::examples::weather::make_weather_model;
 fn write_weather_example() {
     let mut writer = SmithyWriter::new(NamespaceID::new_unchecked("example.weather"));
     let model = make_weather_model();
-    let output = write_model_to_string(&mut writer, &model);
+    let output = write_model_to_string(&mut writer, &model.model);
     assert!(output.is_ok());
     println!("{}", output.unwrap())
 }
